==> guikachu-0.11.tar.gz: guikachu-0.11/src/form-editor/table.h <==
//$Id: table.h,v 1.3 2001/10/09 16:37:13 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_TABLE_H
#define GUIKACHU_FORM_EDITOR_TABLE_H

#include "widget.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Table;
    }
}

#include "resizeable.h"
#include <vector>

#include "table-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Table: public Widget,
		     public Resizeable
	{
	    GUI::FormEditor::TableProperties *editor;

	public:
	    Table (Resources::Form *owner,
		   const string& id);
	    virtual ~Table ();
	    
	    virtual Type get_type () const { return WIDGET_TABLE; };
	    
	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget                 *create_editor ();

	    virtual int get_display_width ();
	    virtual int get_display_height ();

	    Property<int>          num_rows;
	    Property<int>          num_columns;
	    Property<vector<int> > column_width;
	    
	private:
	    // Persistance
	    virtual bool load (StorageNode &node);
	    virtual void save (StorageNode &node) const;
	    virtual void save_rcp (ostream &ostr) const;

	    void update ();
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_TABLE_H */

==> guikachu-0.98.0.tar.gz: guikachu-0.98.0/src/form-editor/table.h <==
//$Id: table.h,v 1.4 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_TABLE_H
#define GUIKACHU_FORM_EDITOR_TABLE_H

#include "widget.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Table;
    }
}

#include "resizeable.h"
#include <vector>

#include "table-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Table: public Widget,
		     public Resizeable
	{
	    GUI::FormEditor::TableProperties *editor;

	public:
	    Table (Resources::Form *owner,
		   const string& id);
	    virtual ~Table ();
	    
	    virtual Type get_type () const { return WIDGET_TABLE; };
	    
	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget                 *create_editor ();

	    Property<int>          num_rows;
	    Property<int>          num_columns;
	    Property<vector<int> > column_width;

	protected:
	    virtual int get_auto_width  ();
	    virtual int get_auto_height ();
	    
	private:
	    // Persistance
	    virtual bool load (StorageNode &node);
	    virtual void save (StorageNode &node) const;
	    virtual void save_rcp (ostream &ostr) const;

	    void update ();
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_TABLE_H */
